************
Introduction
************

.. include:: ../README.rst
    :start-after: xmlschema-introduction-start
    :end-before: xmlschema-introduction-end


License
=======

The *xmlschema* library is distributed under the terms of the
`MIT License <http://opensource.org/licenses/MIT>`_.


Support
=======

This software is hosted on GitHub, refer to the
`xmlschema's project page <https://github.com/brunato/xmlschema>`_
for source code and for an issue tracker.
